summaryrefslogtreecommitdiff
path: root/src/libcamera/ipa_controls.cpp
diff options
context:
space:
mode:
authorLaurent Pinchart <laurent.pinchart@ideasonboard.com>2020-03-01 22:02:37 +0200
committerLaurent Pinchart <laurent.pinchart@ideasonboard.com>2020-03-20 16:47:45 +0200
commite5a9e6e9cd3e12efe9ce078171fbe67d7d41a771 (patch)
treec73bc72211ca61c44eda396151b466d4a7a8c1ab /src/libcamera/ipa_controls.cpp
parent73b7ba9da5fe7b1aec62af091ad36403cd3505c4 (diff)
libcamera: controls: Rename ControlRange to ControlInfo
To prepare for storage of additional information in the ControlRange structure, rename it to ControlInfo. Signed-off-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com> Reviewed-by: Jacopo Mondi <jacopo@jmondi.org>
Diffstat (limited to 'src/libcamera/ipa_controls.cpp')
-rw-r--r--src/libcamera/ipa_controls.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/libcamera/ipa_controls.cpp b/src/libcamera/ipa_controls.cpp
index da4724b1..b1d14190 100644
--- a/src/libcamera/ipa_controls.cpp
+++ b/src/libcamera/ipa_controls.cpp
@@ -18,7 +18,7 @@
* transfer them through the IPA C interface and IPA IPC transports.
*
* A control packet contains a list of entries, each of them describing a single
* control range or control value. The packet starts with a fixed-size header
* described by the ipa_controls_header structure, followed by an array of
* fixed-size entries. Each entry is associated with data, stored either
* directly in the entry, or in a data section after the entries array.
@@ -79,19 +79,19 @@
* | | | | |
* \ | | | |
* +-------------------------+ | |
- * / | ipa_control_range_entry | | hdr.data_offset |
+ * / | ipa_control_info_entry | | hdr.data_offset |
* | | #0 | | |
* Control | +-------------------------+ | |
- * range | | ... | | |
+ * info | | ... | | |
* entries | +-------------------------+ | |
- * | | ipa_control_range_entry | | hdr.size |
+ * | | ipa_control_info_entry | | hdr.size |
* \ | #hdr.entries - 1 | | |
* +-------------------------+ | |
* | empty space (optional) | | |
* +-------------------------+ <--´ . |
* / | ... | | entry[n].offset |
* Data | | ... | | |
* section | | range data for entry #n | <-----´ |
* \ | ... | |
* +-------------------------+ |
* | empty space (optional) | |
@@ -100,8 +100,8 @@
*
* The packet header is identical to the ControlList packet header.
*
* Entries are described by the ipa_control_range_entry structure. They contain
* the numerical ID and type of the control. The control range data is stored
* in the data section as described by the following diagram.
*
* ~~~~
@@ -117,10 +117,10 @@
* ~~~~
*
* The minimum and maximum value are stored in the platform's native data
* format. The ipa_control_range_entry::offset field stores the offset from the
* beginning of the data section to the range data.
*
* Range data in the data section shall be stored in the same order as the
* entries array, shall be aligned to a multiple of 8 bytes, and shall be
* contiguous in memory.
*
@@ -178,18 +178,18 @@ static_assert(sizeof(ipa_control_value_entry) == 16,
"Invalid ABI size change for struct ipa_control_value_entry");
/**
* \struct ipa_control_range_entry
* \brief Description of a serialized ControlRange entry
* \var ipa_control_range_entry::id
* The numerical ID of the control
- * \var ipa_control_range_entry::type
+ * \var ipa_control_info_entry::type
* The type of the control (defined by enum ControlType)
- * \var ipa_control_range_entry::offset
+ * \var ipa_control_info_entry::offset
* The offset in bytes from the beginning of the data section to the control
* range data (shall be a multiple of 8 bytes)
* \var ipa_control_range_entry::padding
* Padding bytes (shall be set to 0)
*/
-static_assert(sizeof(ipa_control_range_entry) == 16,
- "Invalid ABI size change for struct ipa_control_range_entry");
+static_assert(sizeof(ipa_control_info_entry) == 16,
+ "Invalid ABI size change for struct ipa_control_info_entry");
@@ -18,7 +18,7 @@
*
* A control packet contains a list of entries, each of them describing a single
- * control range or control value. The packet starts with a fixed-size header
+ * control info or control value. The packet starts with a fixed-size header
* described by the ipa_controls_header structure, followed by an array of
* fixed-size entries. Each entry is associated with data, stored either
@@ -79,19 +79,19 @@
* / | ... | | entry[n].offset |
* Data | | ... | | |
- * section | | range data for entry #n | <-----´ |
+ * section | | info data for entry #n | <-----´ |
* \ | ... | |
* +-------------------------+ |
@@ -100,8 +100,8 @@
* The packet header is identical to the ControlList packet header.
*
- * Entries are described by the ipa_control_range_entry structure. They contain
- * the numerical ID and type of the control. The control range data is stored
+ * Entries are described by the ipa_control_info_entry structure. They contain
+ * the numerical ID and type of the control. The control info data is stored
* in the data section as described by the following diagram.
*
@@ -117,10 +117,10 @@
*
* The minimum and maximum value are stored in the platform's native data
- * format. The ipa_control_range_entry::offset field stores the offset from the
- * beginning of the data section to the range data.
+ * format. The ipa_control_info_entry::offset field stores the offset from the
+ * beginning of the data section to the info data.
*
@@ -117,10 +117,10 @@
*
- * Range data in the data section shall be stored in the same order as the
+ * Info data in the data section shall be stored in the same order as the
* entries array, shall be aligned to a multiple of 8 bytes, and shall be
* contiguous in memory.
@@ -178,18 +178,18 @@ static_assert(sizeof(ipa_control_value_entry) == 16,
"Invalid ABI size change for struct ipa_control_value_entry");
/**
- * \struct ipa_control_range_entry
- * \brief Description of a serialized ControlRange entry
- * \var ipa_control_range_entry::id
+ * \struct ipa_control_info_entry
+ * \brief Description of a serialized ControlInfo entry
+ * \var ipa_control_info_entry::id
* The numerical ID of the control
@@ -178,18 +178,18 @@ static_assert(sizeof(ipa_control_value_entry) == 16,
* The offset in bytes from the beginning of the data section to the control
- * range data (shall be a multiple of 8 bytes)
- * \var ipa_control_range_entry::padding
+ * info data (shall be a multiple of 8 bytes)
+ * \var ipa_control_info_entry::padding
* Padding bytes (shall be set to 0)
*/